summaryrefslogtreecommitdiffstats
path: root/chrome/browser/tab_contents/web_drop_target.h
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
commit57c6a6579cf274fe37d6196931a3034d90da7113 (patch)
treeec42313580156ccc039b5fee714ee12259cb08ee /chrome/browser/tab_contents/web_drop_target.h
parentb23c9e1f05d474adc327c85d87eacc77554976e0 (diff)
downloadchromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.zip
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.gz
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.bz2
Replace all occurrances of WebContents with TabContents.
Review URL: http://codereview.chromium.org/99177 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@15194 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/tab_contents/web_drop_target.h')
-rw-r--r--chrome/browser/tab_contents/web_drop_target.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/chrome/browser/tab_contents/web_drop_target.h b/chrome/browser/tab_contents/web_drop_target.h
index 9a25b77..36894c8 100644
--- a/chrome/browser/tab_contents/web_drop_target.h
+++ b/chrome/browser/tab_contents/web_drop_target.h
@@ -10,21 +10,21 @@
class InterstitialDropTarget;
class RenderViewHost;
-class WebContents;
+class TabContents;
///////////////////////////////////////////////////////////////////////////////
//
// WebDropTarget
//
// A helper object that provides drop capabilities to a WebContents. The
// DropTarget handles drags that enter the region of the WebContents by
// passing on the events to the renderer.
//
class WebDropTarget : public BaseDropTarget {
public:
// Create a new WebDropTarget associating it with the given HWND and
- // WebContents.
- WebDropTarget(HWND source_hwnd, WebContents* contents);
+ // TabContents.
+ WebDropTarget(HWND source_hwnd, TabContents* contents);
virtual ~WebDropTarget();
void set_is_drop_target(bool is_drop_target) {
@@ -50,8 +50,8 @@ class WebDropTarget : public BaseDropTarget {
DWORD effect);
private:
- // Our associated WebContents.
- WebContents* web_contents_;
+ // Our associated TabContents.
+ TabContents* tab_contents_;
// We keep track of the render view host we're dragging over. If it changes
// during a drag, we need to re-send the DragEnter message. WARNING:
@@ -10,21 +10,21 @@
// WebDropTarget
//
-// A helper object that provides drop capabilities to a WebContents. The
-// DropTarget handles drags that enter the region of the WebContents by
+// A helper object that provides drop capabilities to a TabContents. The
+// DropTarget handles drags that enter the region of the TabContents by
// passing on the events to the renderer.
//